#ifndef NUMBERTEXT_VERSION_H
#define NUMBERTEXT_VERSION_H

#define NUMBERTEXT_VERSION "1.0.11"
#define NUMBERTEXT_VERSION_MAJOR 1
#define NUMBERTEXT_VERSION_MINOR 0
#define NUMBERTEXT_VERSION_MICRO 11



#endif
